@@ -72,6 +72,45 @@ def drop_table(table_name,schema_name=None,if_exists=True,quote_char="`"):
         exist_string = " IF EXISTS"
     return f'''DROP TABLE{exist_string} {schema_string}`{table_name}`;'''
 
+def sql_type_to_python(value):
+    sql_data_types = {
+        "mediumtext":["str"],
+        "mediumblob":[],
+        "varbinary":[],
+        "timestamp":["str","int"],
+        "mediumint":[],
+        "tinytext":["str"],
+        "tinyblob":[],
+        "smallint":["int"],
+        "longtext":["str"],
+        "longblob":[],
+        "datetime":["str"],
+        "varchar":["str"],
+        "tinyint":["int"],
+        "integer":["int"],
+        "decimal":["float"],
+        "boolean":["str","int","bool"],
+        "double":["float"],
+        "binary":[],
+        "bigint":["int"],
+        "float":["float"],
+        "year":["int","str"],
+        "time":[],
+        "text":["str"],
+        "enum":[],
+        "date":["str"],
+        "char":["str"],
+        "bool":["str","int","bool"],
+        "blob":[],
+        "set":[],
+        "int":["int"],
+        "dec":[],
+        "bit":[],
+    }
+    if value in sql_data_types:
+        return sql_data_types[value]
+    return None
+    # if value == ""
 
 
 def strip_comments(value):
