@@ -19,6 +19,7 @@
 import re
 import utils.objectUtils as obj
 import utils.string_format as format
+import facades.sql_convert_facade as sql
 
 
 def bool_to_string(value, **kwargs):
@@ -64,6 +65,45 @@ def bool_to_string(value, **kwargs):
             result = "0"
     return result
 
+def to_bool(value,default=False):
+    '''
+        Convert a string to its boolean equivalent.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {str}
+            the value to convert.
+        [`default`=False] {any}
+            The default value to return if a boolean cannot be determined.
+
+        Return {bool}
+        ----------------------
+        The boolean equivalent if successful, the default value otherwise.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-01-2022 13:40:42
+        `memberOf`: string_conversion
+        `version`: 1.0
+        `method_name`: to_bool
+        * @xxx [06-01-2022 13:42:09]: documentation for to_bool
+    '''
+
+
+    if isinstance(value,(bool)):
+        return value
+
+    True_syns =["yes","y","sure","correct","indeed","right","affirmative","yeah","ya","true","1"]
+    False_syns =["no","n","wrong","incorrect","false","negative","0"]
+    if str(value).lower() in True_syns:
+        return True
+    if str(value).lower() in False_syns:
+        return False
+    return default
+
 def string_to_int(value):
     '''
         Attempts to convert a string to an integer.
@@ -107,4 +147,3 @@ def string_to_int(value):
 
     return None
 
-
