@@ -4,6 +4,7 @@ import string
 import random
 import utils.objectUtils as objUtils
 import utils.string_format as strFormat
+import facades.sql_generate_facade as sql
 
 def hash(value):
     '''
@@ -113,6 +114,9 @@ def title_divider(message='',**kwargs):
         [`line_char`="="] {str}
             The character to use as the "line" of the divider.
 
+        [`print`=True] {bool}
+            if True, this will print the divider it generates
+
         Return {str}
         ----------------------
         The divider string.
@@ -131,6 +135,7 @@ def title_divider(message='',**kwargs):
     length = objUtils.get_kwarg(['length'], 100, int, **kwargs)
     line_char = objUtils.get_kwarg(['line_char'], "=", str, **kwargs)
     white_space = objUtils.get_kwarg(['white_space'], 1, int, **kwargs)
+    print_div = objUtils.get_kwarg(['print'], True, (bool), **kwargs)
 
     if isinstance(line_char,(str,int)) is False:
         line_char = "="
@@ -166,6 +171,8 @@ def title_divider(message='',**kwargs):
         line = f"{char_str}{lchar}{padding}{message}{padding}{rchar}{char_str}"
 
     # print(len(line))
+    if print_div is True:
+        print(line)
     return line
 
 # def is_even(num):
@@ -270,6 +277,31 @@ TYPO_PROXIMITY_KEYBOARD = {
 
 
 def generate_typos(text):
+    '''
+        Generate typo variations of the text provided.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `text` {str}
+            The text to generate typos of.
+
+        Return {list}
+        ----------------------
+        A list of typo strings.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-01-2022 10:29:06
+        `memberOf`: string_generation
+        `version`: 1.0
+        `method_name`: generate_typos
+        @xxx [06-01-2022 10:30:00]: documentation for generate_typos
+    '''
+
+
     if len(text) == 0:
         return []
     typos = []
